#include "reg52.h"					// define 8051 registers
#include <intrins.h>
typedef unsigned char       UB8;        /* 8-bit data */
//============================================
//==================================
// Command table
//==================================
#define ON	1
#define OFF	0
#define DISPALYONOFF(x)	(0xAE|(x&0x01))
#define DISPALYLINE(x)	(0x40|(x&0x3F))
#define PAGEADDRESS(x)	(0xB0|(x&0x0F))
#define COLUMNHIGH(x)	(0x10|(x&0x0F))
#define COLUMNLOW(x)	(0x00|(x&0x0F))
#define ADCSELECT(x)	(0xA0|(x&0x01))
#define DISPLAYREVERSE(x)	(0xA6|(x&0x01))
#define DISPLAYALLON(x)	(0xA4|(x&0x01))
#define BIAS(x)	(0xA2|(x&0x01))
#define READMODIFYWRITE	(0xE0)
#define CLEARMODIFY	(0xEE)
#define INTERNALRESET	(0xE2)
#define COMMONREVERSE(x)	(0xC0|((x&0x01)<<3))
#define POWERCONTROL(x)	(0x28|(x&0x07))
#define V0REGULATOR(x)	(0x20|(x&0x07))
#define ELECTRONICSETCMD	(0x81)
#define ELECTRONICSETCOLUME(x)	(x&0x3F)
#define BOOSTERRATIOCMD	(0xF8)
#define	BOOSTERRATIO(x)	(x&0x03)

// 128*64
#define   MaxColumn    128              //  128 * 64 ~ 240 *64
#define   MaxRow       64              //

// Start Page
#define STARTPAGE	0x00

// Start Line
#define STARTLINE	0x00

// Column Address
#define COLUMNADD 0x00
#define COLUMNADDHIGH ((COLUMNADD >> 4) & 0x0F)
#define COLUMNADDLOW (COLUMNADD & 0x0F)

//DrawPattern
#define FULLON 0xFF
#define HORIZONTAL	0xAA 
#define VERTICAL	0x00
#define CROSSDOT	0x55

//=====================================================
#define 	LCM_PORT P1         	//DB0~DB7,DATA BUS
sbit   		LCM_RS =  P3^0;

sbit  		LCM_RW =  P3^7;
sbit	 	LCM_ENABLE = P3^4;

sbit		LCM_CS1 = P3^1;
sbit		LCM_PS1 = P3^6;
sbit		LCM_RESET = P3^2;
sbit		LCM_C86 = P3^5;

sbit		SCL = P1^6;
sbit		SDI = P1^7;

void Initial_ST7565(void);
void Write_command(UB8);
void Write_data(UB8);
void show(void);


unsigned char code picture[8][128];
unsigned char code picture1[8][128];
unsigned char code picture2[8][128];
unsigned char code picture3[8][128];

void main()
{
P2 = 0x00;
Initial_ST7565();


show();
while(1)
{

}


}


//==================================
//      initial T6963C
//==================================
void Initial_ST7565()
{
	
	LCM_C86 = 1;
	LCM_PS1 = 0;
	LCM_CS1 = 1;
	
	LCM_RESET = 1;
	_nop_();
	LCM_RESET = 0;
	_nop_();
	LCM_RESET = 1;

	Write_command(ADCSELECT(OFF));		//SET ADC=0 S1 to S128
	Write_command(COMMONREVERSE(OFF));		//SET SHL=0 C1 to C64
	Write_command(BIAS(0));		//SET BIAS=1 1/7 Bias, 1/65 Duty

	Write_command(POWERCONTROL(0x07));		//POWER control con.,reg.,follower ON
	Write_command(V0REGULATOR(0x3F));		//Ref. R select 00100--- (max:25)
	
	Write_command(ELECTRONICSETCMD);		//Set Voltage Ref. Mode
	Write_command(ELECTRONICSETCOLUME(0x1F)); 	    //LEVEL 32 xx------0x25  VOP (max:32)

	Write_command(DISPALYLINE(STARTLINE));		//Initial Display Line  01------
	Write_command(PAGEADDRESS(STARTPAGE));		//Set Page From 0

	Write_command(COLUMNHIGH(COLUMNADDHIGH));		//Set Column Address MSB from 00
	Write_command(COLUMNLOW(COLUMNADDLOW));		//Set Column Address LSB from 00
	Write_command(DISPALYONOFF(ON));		//Set Display ON

	Write_command(COMMONREVERSE(ON));		//SET SHL=1 C64 to C1 cause of hardware layout
	Write_command(DISPLAYREVERSE(OFF));	// Normal Display
	Write_command(DISPLAYALLON(OFF));	// Display All Point OFF
	
	Write_command(BOOSTERRATIOCMD);		// Booster
	Write_command(BOOSTERRATIO(0x00));
}
/* //-------------------------------------------------
//          Write Data Function
//-------------------------------------------------
void Write_data(unsigned char datap)
{
         LCM_RS = 1;
         LCM_RW = 0; 
         LCM_PORT=datap;
	   	 LCM_ENABLE = 1;
	     _nop_();
	     LCM_ENABLE = 0;
}
//-------------------------------------------------
//     WRITE_COMMAND
//-------------------------------------------------
void Write_command(unsigned char command)
{
         LCM_RS = 0;
         LCM_RW = 0; 
         LCM_PORT = command;
	 	 LCM_ENABLE = 1;
	 	 _nop_();
	 	 LCM_ENABLE = 0;
}                       */
//-------------------------------------------------
//     WRITE_COMMAND for SPI 4 LINE
//-------------------------------------------------
void Write_command(unsigned char command)
{
	unsigned char bMask;
	LCM_RS = 0;
	LCM_CS1 = 0;

       for (bMask = 0x80; bMask; bMask >>= 1)
           {
            SDI = command & bMask;
            SCL = 1;	
			SCL = 0;
	   }
       LCM_CS1 = 1;
}
//-------------------------------------------------
//     WRITE_DATA for SPI 4 LINE
//-------------------------------------------------
void Write_data(unsigned char datap)
{
	unsigned char bMask;
	LCM_RS = 1;
	LCM_CS1 = 0;

       for (bMask = 0x80; bMask; bMask >>= 1)
           {
            SDI = datap & bMask;
            SCL = 1;	
			SCL = 0;
	   }
       LCM_CS1 = 1;
}

 
//=========================================
void show()
{
unsigned char x,y,Z=0xb0;
for(x = 0;x<8;x++)
 {
   Write_command(Z);
   Z++;
   Write_command(0x10);
   Write_command(0x00);
   for(y = 0;y<128;y++)
      {
	Write_data(0x0f);
      }
 }
}





unsigned char code picture[8][128] ={
0x00,0xFE,0xFE,0xFE,0xFE,0xFE,0xFE,0xFE,
0xFE,0xFE,0xFE,0xFE,0xFE,0xFE,0xFE,0xFE,
0xFE,0xFE,0xFE,0xFE,0xFE,0xFE,0xFE,0xFE,
0xEE,0x6E,0x6E,0x6E,0x6E,0x46,0x46,0x6E,
0x6E,0x46,0x46,0x6E,0x6E,0x66,0xE6,0xEE,
0xFE,0xFE,0xFE,0xFE,0xFE,0xCE,0x0E,0x3E,
0x3E,0x3E,0xBE,0xAE,0x2E,0x2E,0x86,0x06,
0x2E,0xAE,0xAE,0xBE,0xFE,0xFE,0xFE,0xFE,
0xFE,0xFE,0xFE,0xDE,0x9E,0x3E,0x3E,0x7E,
0xFE,0x06,0x06,0xF6,0x3E,0x1E,0x9E,0xDE,
0xFE,0xFE,0xFE,0xFE,0xFE,0xFE,0xFE,0x7E,
0x0E,0x0E,0x56,0x56,0x56,0x56,0x06,0x06,
0x56,0x56,0x56,0x56,0x8E,0x8E,0xDE,0xFE,
0xFE,0xFE,0xFE,0xFE,0xFE,0xFE,0xFE,0xFE,
0xFE,0xFE,0xFE,0xFE,0xFE,0xFE,0xFE,0xFE,
0xFE,0xFE,0xFE,0xFE,0xFE,0xFE,0xFE,0x00,
0x00,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
0xFB,0xDB,0xDB,0x5B,0x40,0x40,0x5B,0x00,
0x00,0x5B,0x40,0x40,0x4B,0xC9,0xD9,0xFB,
0xFF,0xFF,0xFF,0xFF,0xFF,0x6F,0x0F,0x01,
0xF0,0xDA,0xDB,0xC9,0xC0,0x92,0x37,0x36,
0x14,0xC5,0xE5,0xFC,0xFC,0xFF,0xFF,0xFF,
0xFF,0xFF,0xFB,0xFB,0xFB,0x3B,0x02,0xC2,
0xFB,0xF8,0x00,0x02,0xFA,0xFB,0xFB,0x39,
0x39,0xFB,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
0xFF,0xFF,0x05,0x05,0x55,0x55,0x04,0x04,
0x55,0x55,0x05,0x05,0x3F,0x3F,0xFF,0xFF,
0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,
0x00,0xFF,0xFF,0xFF,0xFF,0x3F,0x3F,0xFF,
0xFF,0x7F,0x3F,0x7F,0xFF,0xFF,0x3F,0x3F,
0x3F,0x3F,0xFF,0x3F,0x3F,0xFF,0xFF,0x3F,
0x3F,0xFF,0x7F,0x3F,0xBF,0xBF,0x3F,0x7C,
0xFC,0xBF,0xBF,0x3F,0x3F,0xBF,0xBF,0xFF,
0xFF,0xFF,0x3F,0x3F,0x3F,0xFF,0xFE,0xFE,
0x3F,0x3D,0xBD,0xBD,0x3C,0x7E,0xFE,0xFF,
0xFE,0xFE,0x3C,0x3D,0xBD,0xBF,0x3F,0x7F,
0xFF,0x3F,0x3D,0xFD,0x7C,0x3E,0xBF,0xBF,
0x3F,0x7F,0xFE,0x3C,0x3D,0xBD,0xBD,0x3C,
0x7C,0xFE,0x3F,0x3F,0xFF,0xFF,0xFF,0xFF,
0xFF,0xFF,0xFF,0x3F,0x3F,0x3F,0xFE,0xFC,
0xFD,0x3D,0x3D,0xFD,0xFC,0x3C,0x3E,0xFF,
0xFF,0xFF,0xFF,0xFF,0x7F,0x3F,0xBF,0xBF,
0x3F,0x7F,0xFF,0xFF,0x7F,0x3F,0xBF,0x3F,
0x7F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,
0x00,0xFF,0xFF,0xFF,0xFF,0xFF,0xF0,0xC0,
0xC7,0xF0,0xFE,0xF0,0xC7,0xC0,0xF0,0xFF,
0xC0,0xC0,0xFF,0xC0,0xC0,0xFC,0xF3,0xC0,
0xC0,0xFF,0xEC,0xCC,0xD9,0xD9,0xC3,0xE3,
0xFF,0xFF,0xFF,0xC0,0xC0,0xFF,0xFF,0xFF,
0xC7,0xC0,0xF0,0xF7,0xF0,0xC0,0xC7,0xFF,
0xC0,0xC0,0xFB,0xF3,0xE0,0xCC,0xDF,0xFF,
0xFF,0xFF,0xC0,0xC0,0xDF,0xDF,0xC0,0xE0,
0xFF,0xC0,0xC0,0xFF,0xEC,0xCC,0xD9,0xD9,
0xC3,0xE3,0xFF,0xC0,0xC0,0xFB,0xFB,0xF8,
0xFC,0xFF,0xC0,0xC0,0xDF,0xDF,0xDF,0xDF,
0xFF,0xC7,0xC0,0xF0,0xF7,0xF0,0xC0,0xC7,
0xFF,0xFF,0xFC,0xC1,0xC1,0xFC,0xFF,0xFF,
0xFF,0xFF,0xFF,0xF0,0xE0,0xCF,0xDF,0xDF,
0xCF,0xEF,0xFF,0xF0,0xE0,0xCF,0xDF,0xCF,
0xE0,0xF0,0xFF,0xCF,0xCF,0xFF,0xFF,0x00,
0x00,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
0x7F,0xFF,0xFF,0xFF,0xFF,0xFF,0x7F,0xFF,
0xFF,0xFF,0x7F,0x7F,0x7F,0x7F,0xFF,0xFF,
0xFF,0x7F,0x7F,0x7F,0x7F,0xFF,0xFF,0xFF,
0x7F,0x7F,0x7F,0x7F,0x7F,0xFF,0xFF,0x7F,
0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
0xFF,0xFF,0xFF,0xFF,0x7F,0xFF,0xFF,0xFF,
0x7F,0xFF,0xFF,0xFF,0x7F,0xFF,0xFF,0x7F,
0x7F,0x7F,0x7F,0xFF,0xFF,0xFF,0xFF,0xFF,
0x7F,0xFF,0xFF,0xFF,0x7F,0x7F,0x7F,0xFF,
0xFF,0xFF,0x7F,0x7F,0x7F,0xFF,0xFF,0xFF,
0x7F,0x7F,0x7F,0xFF,0xFF,0xFF,0xFF,0xFF,
0x7F,0xFF,0xFF,0xFF,0x7F,0x7F,0x7F,0xFF,
0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,
0x00,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
0xC0,0xFC,0xF3,0xCF,0xF3,0xFC,0xC0,0xFF,
0xFF,0xE0,0xDF,0xDF,0xDF,0xDF,0xE0,0xFF,
0xFF,0xC0,0xDF,0xDF,0xDF,0xE0,0xFF,0xFF,
0xC0,0xDB,0xDB,0xDB,0xDB,0xFF,0xFF,0xC0,
0xDF,0xDF,0xDF,0xFF,0xFF,0xFF,0xFF,0xDD,
0xFF,0xFF,0xFF,0xFF,0xFE,0xF1,0xCF,0xF1,
0xFE,0xF1,0xCF,0xF1,0xFE,0xFF,0xE0,0xDF,
0xDF,0xDB,0xDB,0xE2,0xFF,0xFF,0xFD,0xFE,
0xC0,0xFF,0xFF,0xDE,0xCF,0xD7,0xDB,0xDC,
0xFF,0xE4,0xDB,0xDB,0xDB,0xE4,0xFF,0xE0,
0xDB,0xDB,0xDB,0xE6,0xFF,0xE7,0xE9,0xEE,
0xC0,0xEF,0xFF,0xC0,0xFB,0xFB,0xFB,0xC0,
0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,
0x00,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
0x83,0x7D,0x7D,0x6D,0x6D,0x8B,0xFF,0x07,
0xF7,0xF7,0xFF,0xB7,0x57,0x57,0x57,0x0F,
0xFF,0x07,0x77,0x77,0x77,0x8F,0xFF,0x01,
0xF7,0xF7,0xF7,0x0F,0xFF,0x05,0xFF,0xFF,
0x8F,0x77,0x77,0x77,0xAF,0xFF,0xFF,0x77,
0xFF,0xFF,0xFF,0xFF,0xFF,0xF7,0xFB,0x01,
0xFF,0xFF,0x7B,0x3D,0x5D,0x6D,0x73,0xFF,
0x93,0x6D,0x6D,0x6D,0x93,0xFF,0xEB,0xF1,
0xEB,0xFF,0x83,0x6D,0x6D,0x6D,0x9B,0xFF,
0x9F,0xA7,0xBB,0x01,0xBF,0xFF,0xFF,0xFF,
0xFF,0xFF,0x01,0x7D,0x7D,0x7D,0x83,0xFF,
0x8F,0x77,0x77,0x77,0x8F,0xF7,0x01,0x77,
0xFF,0x6F,0x57,0x57,0x57,0xB7,0xFF,0xFF,
0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,
0x00,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,
0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,
0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,
0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,
0x7F,0x7C,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,
0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,
0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,
0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,
0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,
0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,
0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,
0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,
0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,
0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,
0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,
0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x00};

unsigned char code picture1[8][128]  ={
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0xC0,0x60,0x20,0x30,0xB0,0x90,0x30,
0x20,0x60,0xC0,0x80,0x00,0x80,0x80,0x80,
0x80,0x80,0x80,0xC0,0x80,0x80,0xC0,0xC0,
0x80,0x80,0x80,0x80,0x80,0xE0,0x38,0x18,
0x8C,0x44,0x24,0x26,0x04,0x04,0x08,0xD8,
0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0xE0,0xB8,0x1C,
0x16,0xE2,0x83,0x41,0x41,0x40,0xE1,0x92,
0x1C,0xF0,0x60,0xB0,0xB0,0xA8,0xC4,0xC4,
0x54,0x44,0x44,0x78,0x40,0x40,0x40,0x40,
0x18,0x0C,0x64,0x16,0x8E,0xC6,0x6C,0x78,
0x13,0x0F,0x88,0xC8,0x20,0x00,0x01,0x02,
0x00,0x00,0x01,0x01,0x01,0x01,0x01,0x00,
0x40,0xE0,0x00,0x00,0x00,0x00,0x00,0x60,
0x60,0x00,0x00,0x00,0x81,0x80,0x00,0x00,
0x03,0x00,0x00,0x00,0x00,0x0A,0x1B,0xF3,
0xE1,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,
0x0F,0x19,0x10,0x10,0x10,0x82,0x84,0x00,
0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x0E,
0x6C,0xFE,0x0F,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,
0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0xFF,0x1F,0x00,0x04,0x04,0x04,0x04,0x04,
0x04,0x04,0x04,0x04,0x0C,0x0C,0x08,0x08,
0x08,0x08,0x18,0x10,0x10,0x30,0x20,0x60,
0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x80,0xC0,
0x40,0x20,0x20,0x00,0x08,0x0F,0x9F,0x00,
0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x08,
0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x02,0x00,0xC4,0x70,0x1A,0x0E,0x04,0x02,
0x02,0x00,0x00,0x0C,0x04,0x12,0x32,0x3A,
0x32,0x04,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x02,
0x18,0x1D,0x1D,0x09,0x02,0x00,0x00,0x00,
0x00,0x00,0x02,0x04,0x0C,0x18,0xF0,0xC0,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x01,0x02,0x06,0x04,0x10,0xB0,
0x40,0x40,0x80,0x80,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x00,
0x00,0x00,0xE0,0xF8,0x1E,0x07,0x01,0x00,
0x00,0x00,0xE0,0xFC,0x02,0x01,0x00,0x00,
0x0F,0x01,0x0C,0x01,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x0F,0x7F,0xC0,0x00,0x00,0x00,0xE0,
0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,
0x78,0x00,0x00,0x00,0x80,0xE0,0x7F,0x3F,
0x06,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x03,0xFF,0xE2,0x02,0x03,0x02,0x06,0x06,
0x06,0x06,0x04,0x06,0x03,0x02,0x00,0x00,
0x00,0x0E,0xFF,0xE3,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x03,0x06,0x0C,0x18,0x10,
0x07,0x3C,0x20,0x60,0x60,0x40,0x40,0x00,
0x80,0x80,0x80,0x80,0x80,0x80,0x80,0xC0,
0x40,0x40,0x40,0x40,0x21,0xE2,0xF4,0x01,
0x03,0x14,0x1C,0x28,0x30,0x00,0x60,0x60,
0x40,0xC0,0xC0,0x80,0x80,0x80,0x80,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x80,0x80,0x80,0x80,0x80,0x00,0xC0,
0x40,0x40,0x20,0x30,0x38,0x1C,0x13,0x11,
0x08,0x04,0x06,0x03,0x01,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x80,0x80,0x40,0x00,0x00,0x00,0x00,
0xC0,0xFF,0x0F,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x03,0x0E,0x18,0x30,0x40,
0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x0F,0xFF,0x40,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x02,0x04,0x04,0x08,0x08,0x50,0xF0,
0x00,0x20,0x20,0x20,0x20,0x00,0x00,0x40,
0x40,0xC0,0x40,0x40,0x40,0x40,0x40,0xF8,
0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0xC3,0x7E,0x00,0x20,0x20,0x20,0x00,
0x10,0x70,0x60,0x88,0xC8,0xA4,0xA4,0x82,
0xA1,0xC0,0xA0,0x90,0x90,0x90,0xE0,0xC0,
0xFF,0xB9,0x80,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,
0x61,0x67,0x6E,0x70,0x60,0x60,0x58,0x40,
0x40,0x48,0x50,0x48,0x44,0x44,0x44,0x64,
0x38,0x3F,0x35,0x31,0x37,0x37,0x31,0x31,
0x31,0x31,0x31,0x31,0x31,0x3F,0x3B,0x34,
0x30,0x32,0x32,0x30,0x34,0x18,0x14,0x10,
0x10,0x10,0x10,0x14,0x18,0x10,0x18,0x1F,
0x18,0x1C,0x1C,0x1C,0x1C,0x1C,0x1C,0x1C,
0x1C,0x1F,0x0D,0x1C,0x1C,0x1C,0x0C,0x1F,
0x1E,0x1C,0x08,0x0A,0x18,0x1A,0x1A,0x0C,
0x08,0x0A,0x08,0x0A,0x08,0x08,0x0C,0x04,
0x0F,0x0F,0x0F,0x07,0x07,0x07,0x07,0x07,
0x07,0x07,0x07,0x07,0x07,0x07,0x03,0x03,
0x03,0x03,0x03,0x03,0x01,0x01,0x01,0x01,
0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00};

unsigned char code picture2[8][128]  ={
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x80,0xC0,0xC0,0xC0,0xE0,
0xE0,0xE0,0xE0,0x60,0x70,0xF0,0xF0,0xF0,
0xF0,0xF0,0xF0,0xF0,0xE0,0xE0,0xE0,0xE0,
0xE0,0xC0,0xC0,0x80,0x80,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0xC0,0xE0,0xF8,0xF8,0xFE,
0xFE,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
0xE1,0xC0,0x80,0x80,0x40,0x1C,0x2C,0x1B,
0x0F,0x0F,0x07,0x07,0x07,0x07,0x03,0x13,
0x23,0x23,0x03,0x03,0x03,0x03,0x03,0x02,
0x1C,0x0C,0x18,0x30,0x20,0xC0,0x80,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,
0x40,0x40,0x60,0x60,0x70,0x70,0x78,0x78,
0x78,0xFC,0xFC,0xFC,0xFC,0xFC,0xFE,0xFE,
0xBE,0x3E,0x3E,0x3C,0x3C,0x7C,0xFC,0xFC,
0xF8,0xF8,0xF8,0xF0,0xF0,0xE0,0xC0,0x80,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0xF0,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x7F,
0x0F,0x07,0x01,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x06,
0x0C,0x70,0xC0,0x00,0x00,0x00,0x00,0x00,
0x80,0x60,0x30,0x18,0x04,0x02,0x01,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x02,
0x00,0x00,0x00,0x01,0x01,0x03,0x03,0x07,
0x09,0x10,0x70,0xF0,0xF8,0xF8,0xFF,0xFF,
0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
0x7E,0x08,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x0F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFC,
0xF8,0xF0,0xC0,0x80,0x88,0x10,0x00,0x00,
0x20,0x00,0x40,0x00,0x00,0x80,0x00,0x80,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x0B,0xFC,0x60,0x18,0x0E,0x03,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,
0x38,0x00,0xA0,0xFF,0xFF,0xFF,0xFF,0xFF,
0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xF9,
0xF8,0xF0,0xE0,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x03,0x0F,0x1F,0x3F,0xFF,
0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
0xFF,0xFE,0xFE,0xFE,0xFE,0xFE,0xBC,0xFC,
0xFC,0xFC,0xFD,0xFC,0xFF,0xFC,0xFE,0xFE,
0xFE,0xFE,0xFE,0xFE,0xFC,0xFC,0xFC,0xFC,
0xFC,0xFC,0xF7,0xF1,0xE0,0xE0,0x00,0x00,
0x80,0x90,0xF0,0xF0,0xF0,0xF0,0xC0,0xD0,
0xF0,0xF0,0xF0,0xF8,0xF8,0xF8,0xF8,0xF8,
0xFC,0xFC,0xFC,0xFC,0xFE,0xFC,0xFE,0xFE,
0xFF,0xFF,0xFF,0xC3,0xFE,0xFF,0xFF,0xFF,
0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
0xFF,0xFF,0xBF,0xC6,0xC0,0xE0,0xF0,0xF8,
0xFC,0xFE,0xFE,0xFE,0xFE,0xFE,0xFE,0xFC,
0xFC,0xF8,0xF0,0xC0,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x01,0x03,0x07,0x07,0x0F,0x1F,0x1F,
0x3F,0x3F,0x7F,0x7F,0xFF,0xFF,0xFF,0xFF,
0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFE,0xFF,
0xFF,0xFF,0xFF,0xFF,0x7F,0x7F,0x7F,0x7F,
0x3F,0x3F,0x3F,0x1F,0x3F,0xFF,0xFF,0xFF,
0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
0xFF,0x7F,0x7F,0x7F,0x7F,0x3F,0x3F,0x3F,
0x3F,0x1F,0x1F,0x1F,0x1F,0x1F,0x1F,0x1F,
0x0F,0x07,0x03,0x01,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x80,0xC0,0x00,0x20,0xA0,0xB0,0x90,
0xA1,0x81,0x81,0xC9,0x09,0x4B,0x6B,0x2B,
0x43,0x2F,0x13,0x93,0x1B,0x97,0x1F,0x07,
0x17,0x0F,0x97,0x97,0x87,0x57,0x57,0x4F,
0x03,0x2B,0x2B,0x23,0x2B,0x21,0x29,0x21,
0x20,0x10,0xE0,0x20,0x90,0x90,0x48,0x98,
0xB0,0x48,0xA8,0x68,0x28,0x50,0x18,0x21,
0xB1,0x03,0x3B,0x4F,0x13,0x0F,0x8F,0x8F,
0x8F,0x87,0x47,0x47,0x0F,0x2F,0x37,0x2F,
0x0F,0x33,0x03,0x21,0x01,0x21,0x20,0x20,
0x20,0x20,0x20,0x20,0x30,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x02,0x00,0x00,0x02,0x02,0x02,0x02,0x04,
0x01,0x04,0x04,0x00,0x02,0x02,0x00,0x01,
0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x03,0x02,0x02,0x00,0x02,0x03,0x00,0x02,
0x02,0x02,0x02,0x01,0x01,0x01,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00};

unsigned char code picture3[8][128]  ={
0x00,0x00,0x00,0x00,0x00,0x00,0x0E,0x31,
0x62,0x46,0x86,0x08,0x30,0x70,0x60,0x80,
0x80,0x80,0x60,0xE0,0x60,0x60,0x60,0x60,
0x60,0x60,0x60,0x60,0x60,0xC0,0x80,0x80,
0x40,0x60,0xB0,0x18,0x8C,0x86,0x62,0x31,
0x0E,0x0C,0xF0,0x00,0x00,0x00,0x00,0x00,
0x00,0x80,0x80,0x00,0x00,0x00,0x80,0x80,
0x80,0x00,0x00,0x00,0x80,0x80,0x00,0x80,
0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,
0x00,0x80,0x80,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,
0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,
0x00,0x80,0x80,0x80,0x00,0x00,0x00,0x00,
0x00,0x80,0x80,0x80,0x00,0x00,0x80,0x80,
0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x80,0xC0,0x10,
0x0D,0x08,0x06,0x01,0x01,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x0F,0x19,
0x15,0x15,0x61,0x15,0x31,0x32,0x2A,0x14,
0x73,0x32,0x0E,0x09,0x06,0x02,0x0D,0x10,
0x80,0xE0,0xFF,0x00,0x00,0x00,0x00,0x00,
0x00,0x03,0x7F,0xFE,0x80,0xFC,0x3F,0x03,
0x3F,0xFC,0x80,0xFE,0x7F,0x03,0x00,0xFF,
0xFF,0x19,0x19,0x19,0x19,0x19,0x19,0x00,
0x00,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x7C,0xFF,0x83,0x01,0x01,0x01,
0x83,0xC7,0x82,0x00,0x00,0x7C,0xFF,0x83,
0x01,0x01,0x01,0x01,0x83,0xFF,0x7C,0x00,
0x00,0xFF,0xFF,0x07,0x3E,0xF0,0xC0,0xF0,
0x3E,0x07,0xFF,0xFF,0x00,0x00,0xFF,0xFF,
0x19,0x19,0x19,0x19,0x19,0x19,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0xFF,0x00,0x00,
0x00,0x10,0x30,0x08,0x08,0x08,0x18,0x10,
0x70,0x60,0xC0,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0xC0,0xE0,0x60,0x10,
0x18,0x08,0x08,0x0C,0x30,0x30,0x00,0x00,
0x00,0x00,0xFF,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x03,0x03,0x03,0x00,0x00,
0x00,0x03,0x03,0x03,0x00,0x00,0x00,0x03,
0x03,0x03,0x03,0x03,0x03,0x03,0x03,0x00,
0x00,0x03,0x03,0x03,0x03,0x03,0x03,0x03,
0x00,0x00,0x00,0x01,0x01,0x03,0x03,0x03,
0x03,0x01,0x00,0x00,0x00,0x00,0x01,0x01,
0x03,0x03,0x03,0x03,0x01,0x01,0x00,0x00,
0x00,0x03,0x03,0x00,0x00,0x01,0x03,0x01,
0x00,0x00,0x03,0x03,0x00,0x00,0x03,0x03,
0x03,0x03,0x03,0x03,0x03,0x03,0x00,0x00,
0x00,0x06,0x66,0x61,0x11,0x11,0x1E,0x78,
0x70,0xE0,0xC0,0x80,0x00,0x00,0x00,0x00,
0x00,0x00,0x71,0x80,0x80,0x80,0x80,0x70,
0x80,0x80,0x80,0x80,0x61,0x61,0x80,0xE0,
0x70,0x30,0x50,0x30,0x30,0x30,0x10,0x70,
0x9E,0x97,0x11,0x61,0x62,0x06,0x06,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x80,0xF0,0x7C,
0x8C,0xF4,0x7C,0x0C,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x80,0xC0,
0x60,0xB0,0x98,0xC8,0x68,0x2C,0x24,0x24,
0x24,0x64,0xE4,0xCC,0x18,0xF8,0xF0,0x00,
0x00,0x00,0x80,0xF0,0x7C,0x8C,0xE4,0x64,
0x24,0x24,0x24,0x24,0x24,0x64,0xC4,0x8C,
0x1C,0xF8,0xF0,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x01,
0xC0,0xE0,0x30,0x19,0x09,0x09,0x06,0x06,
0x0E,0x1E,0x38,0xE8,0x98,0x88,0x88,0x88,
0x08,0x08,0x08,0x08,0x7F,0x7F,0xC1,0xC0,
0x90,0x10,0x60,0x60,0x70,0x70,0x80,0xC0,
0xC0,0x61,0x7F,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0xE0,0xFC,0x1F,0xE3,0xFC,
0x1F,0x03,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0xC0,0xF8,0xFF,0x07,0xF9,
0xFE,0x07,0x01,0x00,0x00,0x00,0x00,0x80,
0xC0,0xC0,0x41,0xC1,0xC1,0x01,0x01,0x00,
0xE0,0xFC,0x1F,0xE3,0xFC,0x1F,0x03,0x00,
0x00,0x00,0x00,0x80,0xE0,0x7C,0x9F,0xE3,
0x7C,0x1F,0x03,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x80,0x80,0x70,0x08,
0x0F,0x0F,0xF0,0x90,0x9E,0x1C,0x90,0x90,
0x1E,0x6C,0xC8,0x67,0x68,0x68,0x6A,0x68,
0x69,0x69,0x86,0x78,0xE0,0xC1,0x01,0x06,
0x0A,0x09,0x08,0x08,0x08,0x08,0x09,0x08,
0x0E,0x17,0x71,0x80,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x18,0x1F,0x17,0x10,0x13,0x13,0x12,
0x12,0x12,0x12,0x12,0x12,0x1A,0x1E,0x06,
0x00,0x00,0x00,0x00,0x07,0x0F,0x0C,0x19,
0x11,0x13,0x12,0x12,0x12,0x1A,0x0B,0x09,
0x0D,0x06,0x03,0x01,0x00,0x00,0x18,0x1F,
0x17,0x10,0x13,0x13,0x12,0x12,0x12,0x12,
0x12,0x1B,0x09,0x0D,0x06,0x07,0x03,0x01,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x1F,0x1F,0xE0,0x80,
0x00,0x00,0xFF,0x00,0xF2,0x13,0x16,0x96,
0x96,0x96,0x66,0x66,0x66,0x66,0x67,0xF2,
0x66,0x66,0x96,0x00,0xFF,0x7F,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x80,0xE0,0x1F,0x00,0x00,0x00,0x00,
0x00,0x00,0x70,0xF0,0xC0,0x00,0x80,0xF0,
0x70,0xF0,0x80,0x00,0xC0,0xF0,0x70,0x00,
0x80,0xE0,0x60,0x30,0x30,0x30,0x30,0x70,
0xE0,0x40,0x00,0x00,0x80,0xC0,0x60,0xF0,
0xF0,0x00,0x00,0xC0,0xE0,0x30,0x30,0x30,
0xF0,0xE0,0x00,0xC0,0xE0,0x30,0x30,0x30,
0xE0,0xC0,0x00,0xC0,0xE0,0x70,0x30,0x30,
0x70,0x60,0x00,0x00,0x00,0x80,0xE0,0xF0,
0xF0,0x00,0x00,0x00,0x00,0xC0,0xF0,0x30,
0xF0,0xC0,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x70,0x49,
0x0F,0x46,0x46,0x68,0x52,0x51,0x6F,0x14,
0x56,0x14,0x0C,0x12,0x16,0x16,0x12,0x1C,
0x6A,0x45,0x51,0x76,0x4B,0x4B,0x40,0x40,
0x40,0x40,0x60,0x40,0x40,0x60,0x40,0x46,
0x49,0x29,0x70,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x0F,0x7F,0x70,0x7F,0x07,
0x00,0x07,0x7F,0x70,0x7F,0x0F,0x00,0x00,
0x0F,0x3F,0x30,0x60,0x60,0x66,0x66,0x76,
0x3E,0x1E,0x00,0x00,0x01,0x00,0x00,0x7F,
0x7F,0x00,0x00,0x60,0x70,0x78,0x6C,0x66,
0x63,0x61,0x00,0x1C,0x3F,0x63,0x63,0x63,
0x3F,0x1C,0x00,0x1F,0x3F,0x63,0x63,0x63,
0x3F,0x1E,0x00,0x1C,0x1E,0x1B,0x18,0x7F,
0x7F,0x18,0x00,0x70,0x7E,0x0F,0x0D,0x0C,
0x0D,0x0F,0x7E,0x70,0x00,0x00,0x00,0x00};
